==> ejc-outcontract-api-3.0.0-20220107.014412-4-sources.jar: com/ejianc/foundation/outcontract/vo/OutcontractSubcontractTotalPriceVO.java <==
package com.ejianc.foundation.outcontract.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包工程总价汇总表
 * 
 * @author generator
 * 
 */
public class OutcontractSubcontractTotalPriceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long outcontractId; // 合同id
    private String itemName; // 分项名称
    private String unit; // 单位
    private BigDecimal provisionalQuantity; // 暂定工程量
    private BigDecimal taxAllUnitPrice; // 含税综合单价
    private BigDecimal totalPrice; // 合计
    private String remark; // 备注
    

    public Long getOutcontractId() {
        return outcontractId;
    }

    public void setOutcontractId(Long outcontractId) {
        this.outcontractId = outcontractId;
    }
    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getProvisionalQuantity() {
        return provisionalQuantity;
    }

    public void setProvisionalQuantity(BigDecimal provisionalQuantity) {
        this.provisionalQuantity = provisionalQuantity;
    }
    public BigDecimal getTaxAllUnitPrice() {
        return taxAllUnitPrice;
    }

    public void setTaxAllUnitPrice(BigDecimal taxAllUnitPrice) {
        this.taxAllUnitPrice = taxAllUnitPrice;
    }
    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-outcontract-api-3.0.0-20230227.085755-163-sources.jar: com/ejianc/foundation/outcontract/vo/OutcontractSubcontractTotalPriceVO.java <==
package com.ejianc.foundation.outcontract.vo;

import java.math.BigDecimal;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包工程总价汇总表
 * 
 * @author generator
 * 
 */
public class OutcontractSubcontractTotalPriceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long outcontractId; // 合同id
    private String itemName; // 分项名称
    private String unit; // 单位
    private BigDecimal provisionalQuantity; // 暂定工程量
    private BigDecimal taxAllUnitPrice; // 含税综合单价
    private BigDecimal totalPrice; // 合计
    private String remark; // 备注
    
    private String errorMsg; // 导入错误信息
    

    public Long getOutcontractId() {
        return outcontractId;
    }

    public void setOutcontractId(Long outcontractId) {
        this.outcontractId = outcontractId;
    }
    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getProvisionalQuantity() {
        return provisionalQuantity;
    }

    public void setProvisionalQuantity(BigDecimal provisionalQuantity) {
        this.provisionalQuantity = provisionalQuantity;
    }
    public BigDecimal getTaxAllUnitPrice() {
        return taxAllUnitPrice;
    }

    public void setTaxAllUnitPrice(BigDecimal taxAllUnitPrice) {
        this.taxAllUnitPrice = taxAllUnitPrice;
    }
    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

	public String getErrorMsg() {
		return errorMsg;
	}

	public void setErrorMsg(String errorMsg) {
		this.errorMsg = errorMsg;
	}
    
}
